@@ -236,10 +236,10 @@ class Mechanism:
 
         if isinstance(self.pos, np.ndarray):
             for v in self.vectors:
-                v.zero(self.pos.size)
+                v.zero(self.pos.shape[0])
 
             for j in self.joints:
-                j.zero(self.pos.size)
+                j.zero(self.pos.shape[0])
 
             if isinstance(self.vel, np.ndarray):
                 assert self.pos.size == self.vel.size, "vel input size does not match pos input size."
@@ -402,12 +402,14 @@ class Mechanism:
             print('--------\n')
             if not to_five:
                 mechanism_data = [[v, v.r, np.rad2deg(v.theta), v.x, v.y] for v in self.positions]
+                joint_data = [[j, j.x_pos, j.y_pos] for j in sorted(self.joints, key=lambda x: x.name)]
             else:
                 mechanism_data = [[v, f'{v.r:.5f}', f'{np.rad2deg(v.theta):.5f}', f'{v.x:.5f}', f'{v.y:.5f}'] for v
                                   in self.positions]
+                joint_data = [[j, f'{j.x_pos:.5f}', f'{j.y_pos:.5f}'] for j in
+                              sorted(self.joints, key=lambda x: x.name)]
             Data(mechanism_data, headers=['Vector', 'R', 'Theta', 'x', 'y']).print(table=True)
             print('')
-            joint_data = [[j, j.x_pos, j.y_pos] for j in sorted(self.joints, key=lambda x: x.name)]
             Data(joint_data, headers=['Joint', 'x', 'y']).print(table=True)
             print('')
 
@@ -499,7 +501,7 @@ class Mechanism:
                 ax.quiver(j.x_pos, j.y_pos, j.x_acc, j.y_acc, angles='xy', scale_units='xy', color='orange', zorder=3)
 
             if not velocity and not acceleration and show_joints:
-                ax.annotate(j.name, (j.x_pos, j.y_pos), size='large')
+                ax.annotate(j.name, (j.x_pos, j.y_pos), size='large', zorder=5)
 
         return fig, ax
 
